==> gcloud-rest-datastore-1.0.0.tar.gz: gcloud-rest-datastore-1.0.0/gcloud/rest/datastore/__init__.py <==
from pkg_resources import get_distribution
__version__ = get_distribution('gcloud-rest').version

from gcloud.rest.datastore.constants import CompositeFilterOperator
from gcloud.rest.datastore.constants import Consistency
from gcloud.rest.datastore.constants import Direction
from gcloud.rest.datastore.constants import Mode
from gcloud.rest.datastore.constants import MoreResultsType
from gcloud.rest.datastore.constants import Operation
from gcloud.rest.datastore.constants import PropertyFilterOperator
from gcloud.rest.datastore.constants import ResultType
from gcloud.rest.datastore.datastore import Datastore
from gcloud.rest.datastore.datastore import SCOPES
from gcloud.rest.datastore.datastore_operation import DatastoreOperation
from gcloud.rest.datastore.entity import Entity
from gcloud.rest.datastore.entity import EntityResult
from gcloud.rest.datastore.filter import CompositeFilter
from gcloud.rest.datastore.filter import Filter
from gcloud.rest.datastore.filter import PropertyFilter
from gcloud.rest.datastore.key import Key
from gcloud.rest.datastore.key import PathElement
from gcloud.rest.datastore.property_order import PropertyOrder
from gcloud.rest.datastore.query import GQLQuery
from gcloud.rest.datastore.query import Query
from gcloud.rest.datastore.query import QueryResultBatch
from gcloud.rest.datastore.value import Value


__all__ = ['__version__', 'CompositeFilter', 'CompositeFilterOperator',
           'Consistency', 'Datastore', 'DatastoreOperation', 'Direction',
           'Entity', 'EntityResult', 'Filter', 'GQLQuery', 'Key', 'Mode',
           'MoreResultsType', 'Operation', 'PathElement', 'PropertyFilter',
           'PropertyFilterOperator', 'PropertyOrder', 'Query',
           'QueryResultBatch', 'ResultType', 'SCOPES', 'Value']

==> gcloud-rest-datastore-1.1.0.tar.gz: gcloud-rest-datastore-1.1.0/gcloud/rest/datastore/__init__.py <==
from pkg_resources import get_distribution
__version__ = get_distribution('gcloud-rest').version

from gcloud.rest.datastore.constants import CompositeFilterOperator
from gcloud.rest.datastore.constants import Consistency
from gcloud.rest.datastore.constants import Direction
from gcloud.rest.datastore.constants import Mode
from gcloud.rest.datastore.constants import MoreResultsType
from gcloud.rest.datastore.constants import Operation
from gcloud.rest.datastore.constants import PropertyFilterOperator
from gcloud.rest.datastore.constants import ResultType
from gcloud.rest.datastore.datastore import Datastore
from gcloud.rest.datastore.datastore import SCOPES
from gcloud.rest.datastore.datastore_operation import DatastoreOperation
from gcloud.rest.datastore.entity import Entity
from gcloud.rest.datastore.entity import EntityResult
from gcloud.rest.datastore.filter import CompositeFilter
from gcloud.rest.datastore.filter import Filter
from gcloud.rest.datastore.filter import PropertyFilter
from gcloud.rest.datastore.key import Key
from gcloud.rest.datastore.key import PathElement
from gcloud.rest.datastore.lat_lng import LatLng
from gcloud.rest.datastore.property_order import PropertyOrder
from gcloud.rest.datastore.query import GQLQuery
from gcloud.rest.datastore.query import Query
from gcloud.rest.datastore.query import QueryResultBatch
from gcloud.rest.datastore.value import Value


__all__ = ['__version__', 'CompositeFilter', 'CompositeFilterOperator',
           'Consistency', 'Datastore', 'DatastoreOperation', 'Direction',
           'Entity', 'EntityResult', 'Filter', 'GQLQuery', 'Key', 'LatLng',
           'Mode', 'MoreResultsType', 'Operation', 'PathElement',
           'PropertyFilter', 'PropertyFilterOperator', 'PropertyOrder',
           'Query', 'QueryResultBatch', 'ResultType', 'SCOPES', 'Value']
